@@ -41,11 +41,11 @@ class ImageData(object):
     The container will always have at least the mipmap level 0.
     '''
 
-    __slots__ = ('fmt', 'mipmaps')
+    __slots__ = ('fmt', 'mipmaps', 'source')
     _supported_fmts = ('rgb', 'rgba', 'bgr', 'bgra',
             's3tc_dxt1', 's3tc_dxt3', 's3tc_dxt5')
 
-    def __init__(self, width, height, fmt, data):
+    def __init__(self, width, height, fmt, data, source=None):
         assert fmt in ImageData._supported_fmts
 
         #: Decoded image format, one of a available texture format
@@ -55,6 +55,9 @@ class ImageData(object):
         self.mipmaps = {}
         self.add_mipmap(0, width, height, data)
 
+        #: Image source, if available
+        self.source = source
+
     def release_data(self):
         mm = self.mipmaps
         for item in mm.itervalues():
@@ -94,8 +97,8 @@ class ImageData(object):
         return len(self.mipmaps) > 1
 
     def __repr__(self):
-        return '<ImageData width=%d height=%d fmt=%s with %d images>' % (
-                self.width, self.height, self.fmt, len(self.mipmaps))
+        return '<ImageData width=%d height=%d fmt=%s source=%r with %d images>' % (
+                self.width, self.height, self.fmt, self.source, len(self.mipmaps))
 
     def add_mipmap(self, level, width, height, data):
         '''Add a image for a specific mipmap level.
