@@ -255,6 +255,8 @@ class LabelBase(object):
         '''
 
         options = self.options
+        render_text = self._render_text
+        get_extents = self.get_extents
         uw, uh = self.text_size
         w, h = 0, 0
         x, y = 0, 0
@@ -272,14 +274,15 @@ class LabelBase(object):
         # no width specified, faster method
         if uw is None:
             for line in self.text.split('\n'):
-                lw, lh = self.get_extents(line)
+                lw, lh = get_extents(line)
                 if real:
                     x = 0
                     if halign == 'center':
                         x = int((self.width - lw) / 2.)
                     elif halign == 'right':
                         x = int(self.width - lw)
-                    self._render_text(line, x, y)
+                    if len(line):
+                        render_text(line, x, y)
                     y += int(lh)
                 else:
                     w = max(w, int(lw))
@@ -298,11 +301,12 @@ class LabelBase(object):
                 glyphs = list(set(self.text)) + ['.']
                 for glyph in glyphs:
                     if not glyph in cache:
-                        cache[glyph] = self.get_extents(glyph)
+                        cache[glyph] = get_extents(glyph)
+
 
             # Shorten the text that we actually display
             text = self.text
-            if options['shorten'] and self.get_extents(text)[0] > uw:
+            if options['shorten'] and get_extents(text)[0] > uw:
                 text = self.shorten(text)
 
             # first, split lines
@@ -364,8 +368,8 @@ class LabelBase(object):
                         x = int(self.width - size[0])
                     for glyph in glyphs:
                         lw, lh = cache[glyph]
-                        if glyph != '\n':
-                            self._render_text(glyph, x, y)
+                        if glyph != ' ' and glyph != '\n':
+                            render_text(glyph, x, y)
                         x += lw
                     y += size[1]
 
@@ -400,25 +404,17 @@ class LabelBase(object):
                         mipmap=mipmap)
             else:
                 texture = Texture.create_from_data(data, mipmap=mipmap)
+                data = None
             texture.flip_vertical()
+            texture.add_reload_observer(self._texture_refresh)
         elif self.width != texture.width or self.height != texture.height:
             if data is None:
                 texture = Texture.create(size=self.size, mipmap=mipmap)
             else:
                 texture = Texture.create_from_data(data, mipmap=mipmap)
+                data = None
             texture.flip_vertical()
-        '''
-        # Avoid that for the moment.
-        # The thing is, as soon as we got a region, the blitting is not going in
-        # the right position cause of previous flip_vertical
-        # In addition, as soon as we have a region, we are not testing from the
-        # original texture. Mean we'll have region of region of region.
-        # Take more time to implement a fix for it, if it's needed.
-        else:
-            print 'get region ??', self, self.width, self.height
-            texture = texture.get_region(
-                0, 0, self.width, self.height)
-        '''
+            texture.add_reload_observer(self._texture_refresh)
 
         self.texture = texture
 
@@ -428,6 +424,9 @@ class LabelBase(object):
         if data is not None and data.width > 1:
             texture.blit_data(data)
 
+    def _texture_refresh(self, *l):
+        self.refresh()
+
     def refresh(self):
         '''Force re-rendering of the text
         '''
