@@ -4,46 +4,56 @@ Providers
 
 '''
 
-import sys
 import os
 
+from kivy.utils import platform as core_platform
 from kivy.logger import Logger
-from kivy.input.providers.tuio import *
-from kivy.input.providers.mouse import *
 
-if sys.platform == 'win32' or 'KIVY_DOC' in os.environ:
+__import__('kivy.input.providers.tuio')
+__import__('kivy.input.providers.mouse')
+
+platform = core_platform()
+
+if platform == 'win' or 'KIVY_DOC' in os.environ:
     try:
-        from kivy.input.providers.wm_touch import *
-        from kivy.input.providers.wm_pen import *
+        __import__('kivy.input.providers.wm_touch')
+        __import__('kivy.input.providers.wm_pen')
     except:
         err = 'Input: WM_Touch/WM_Pen not supported by your version of Windows'
         Logger.warning(err)
 
-if sys.platform == 'darwin' or 'KIVY_DOC' in os.environ:
+if platform == 'macosx' or 'KIVY_DOC' in os.environ:
     try:
-        from kivy.input.providers.mactouch import *
+        __import__('kivy.input.providers.mactouch')
     except:
         err = 'Input: MacMultitouchSupport is not supported by your system'
         Logger.exception(err)
 
-if sys.platform == 'linux2' or 'KIVY_DOC' in os.environ:
+if platform == 'linux' or 'KIVY_DOC' in os.environ:
     try:
-        from kivy.input.providers.probesysfs import *
+        __import__('kivy.input.providers.probesysfs')
     except:
         err = 'Input: ProbeSysfs is not supported by your version of linux'
         Logger.exception(err)
     try:
-        from kivy.input.providers.mtdev import *
+        __import__('kivy.input.providers.mtdev')
     except:
         err = 'Input: MTDev is not supported by your version of linux'
         Logger.exception(err)
     try:
-        from kivy.input.providers.hidinput import *
+        __import__('kivy.input.providers.hidinput')
     except:
         err = 'Input: HIDInput is not supported by your version of linux'
         Logger.exception(err)
+
+if platform == 'android' or 'KIVY_DOC' in os.environ:
     try:
-        from kivy.input.providers.linuxwacom import *
+        __import__('kivy.input.providers.linuxwacom')
     except:
         err = 'Input: LinuxWacom is not supported by your version of linux'
         Logger.exception(err)
+    try:
+        __import__('kivy.input.providers.androidjoystick')
+    except:
+        err = 'Input: AndroidJoystick is not supported by your version of linux'
+        Logger.exception(err)
