@@ -27,13 +27,13 @@ None, a "POST" request will be done. It's up to you to adjust
 Example of fetching twitter trends::
 
     def got_twitter_trends(req, result):
-        trends = result['trends']
+        trends = result[0]['trends']
         print 'Last %d twitter trends:' % len(trends),
         for trend in trends:
             print trend['name'],
         print '!'
 
-    req = UrlRequest('http://api.twitter.com/1/trends.json',
+    req = UrlRequest('https://api.twitter.com/1/trends/1.json',
             got_twitter_trends)
 
 Example of Posting data (adapted from httplib example)::
@@ -48,8 +48,8 @@ Example of Posting data (adapted from httplib example)::
         '@action': 'show'})
     headers = {'Content-type': 'application/x-www-form-urlencoded',
               'Accept': 'text/plain'}
-    req = UrlRequest('bugs.python.org', on_success=bug_posted, body=params,
-            headers=headers)
+    req = UrlRequest('bugs.python.org', on_success=bug_posted, req_body=params,
+            req_headers=headers)
 
 
 '''
@@ -58,12 +58,14 @@ from collections import deque
 from threading import Thread
 from json import loads
 from httplib import HTTPConnection
+from time import sleep
 
+HTTPSConnection = None
 try:
     from httplib import HTTPSConnection
 except ImportError:
     # on android platform, this is not available yet.
-    HTTPSConnection = None
+    pass
 
 from urlparse import urlparse
 from kivy.clock import Clock
@@ -72,6 +74,9 @@ from kivy.clock import Clock
 class UrlRequest(Thread):
     '''Url request. See module documentation for usage.
 
+    .. versionchanged::
+        Add `method` parameters
+
     :Parameters:
         `url`: str
             Complete url string to call.
@@ -97,10 +102,13 @@ class UrlRequest(Thread):
             on_progress.
         `timeout`: int, default to None
             If set, blocking operations will timeout after that many seconds.
+        `method'`: str, default to 'GET' (or 'POST' if body)
+            HTTP method to use
     '''
 
     def __init__(self, url, on_success=None, on_error=None, on_progress=None,
-            req_body=None, req_headers=None, chunk_size=8192, timeout=None):
+            req_body=None, req_headers=None, chunk_size=8192, timeout=None,
+            method=None):
         super(UrlRequest, self).__init__()
         self._queue = deque()
         self._trigger_result = Clock.create_trigger(self._dispatch_result, 0)
@@ -116,6 +124,7 @@ class UrlRequest(Thread):
         self._resp_length = -1
         self._chunk_size = chunk_size
         self._timeout = timeout
+        self._method = method
 
         #: Url of the request
         self.url = url
@@ -182,7 +191,10 @@ class UrlRequest(Thread):
             path += '#' + parse.fragment
 
         # send request
-        req.request('GET', path, body, headers or {})
+        method = self._method
+        if method is None:
+            method = 'GET' if body is None else 'POST'
+        req.request(method, path, body, headers or {})
 
         # read header
         resp = req.getresponse()
@@ -314,10 +326,20 @@ class UrlRequest(Thread):
         '''
         return self._chunk_size
 
+    def wait(self, delay=0.5):
+        '''If you want a sync request, you can call the wait() method. It will
+        wait for the request to be finished (until :data:`resp_status` is not
+        None)
+
+        .. versionadded:: 1.1.0
+        '''
+        while self.resp_status is None:
+            self._dispatch_result(delay)
+            sleep(delay)
+
 
 if __name__ == '__main__':
 
-    from time import sleep
     from pprint import pprint
 
     def on_success(req, result):
