@@ -5,7 +5,8 @@ Support
 Activate other framework/toolkit inside our event loop
 '''
 
-__all__ = ('install_gobject_iteration', 'install_twisted_reactor')
+__all__ = ('install_gobject_iteration', 'install_twisted_reactor',
+    'install_android')
 
 
 def install_gobject_iteration():
@@ -36,6 +37,77 @@ def install_gobject_iteration():
     Clock.schedule_interval(_gobject_iteration, 0)
 
 
+def install_android():
+    '''Install hooks for android platform.
+
+    * Automaticly sleep when the device is paused
+    * Auto kill the application is the return key is hitted
+    '''
+    try:
+        import android
+    except ImportError:
+        print 'Android lib is missing, cannot install android hooks'
+        return
+
+    from kivy.clock import Clock
+    from kivy.logger import Logger
+    import pygame
+
+    Logger.info('Support: Android install hooks')
+
+    # Init the library
+    android.init()
+    android.map_key(android.KEYCODE_MENU, pygame.K_MENU)
+
+    # Check if android must be paused or not
+    # If pause is asked, just leave the app.
+    def android_check_pause(*largs):
+        # do nothing until android ask for it.
+        if not android.check_pause():
+            return
+
+        from kivy.app import App
+        from kivy.base import stopTouchApp
+        from kivy.logger import Logger
+        from kivy.core.window import Window
+
+        # try to get the current running application
+        Logger.info('Android: Must to in sleep mode, check the app')
+        app = App.get_running_app()
+
+        # no running application, stop our loop.
+        if app is None:
+            Logger.info('Android: No app running, stop everything.')
+            stopTouchApp()
+            return
+
+        # try to go to pause mode
+        if app.dispatch('on_pause'):
+            Logger.info('Android: App paused, now wait for resume.')
+
+            # app goes in pause mode, wait.
+            android.wait_for_resume()
+
+            # is it a stop or resume ?
+            if android.check_stop():
+                # app must stop
+                Logger.info('Android: Android want to close our app.')
+                stopTouchApp()
+            else:
+                # app resuming now !
+                Logger.info('Android: Android resumed, resume the app')
+                app.dispatch('on_resume')
+                Window.canvas.ask_update()
+                Logger.info('Android: App resume completed.')
+
+        # app don't support pause mode, just stop it.
+        else:
+            Logger.info('Android: App doesn\'t support pause mode, stop.')
+            stopTouchApp()
+
+    Clock.schedule_interval(android_check_pause, 0)
+
+
 def install_twisted_reactor(**kwargs):
     '''Installs a threaded twisted reactor, which will schedule one
     reactor iteration before the next frame only when twisted needs
