@@ -39,6 +39,19 @@ _kivy_modules = [
     'kivy.lib.osc.OSC',
     'kivy.lib.osc.oscAPI',
     'kivy.lib.mtdev',
+    'kivy.lib.debug',
+    'kivy.factory_registers',
+    'kivy.input.providers',
+    'kivy.input.providers.tuio',
+    'kivy.input.providers.mouse',
+    'kivy.input.providers.wm_common',
+    'kivy.input.providers.wm_touch',
+    'kivy.input.providers.wm_pen',
+    'kivy.input.providers.hidinput',
+    'kivy.input.providers.linuxwacom',
+    'kivy.input.providers.mactouch',
+    'kivy.input.providers.mouse',
+    'kivy.input.providers.mtdev',
 
     # compiled modules
     'kivy.event',
