@@ -13,14 +13,15 @@ Read first: :doc:`api-kivy.uix.widget`
     :doc:`api-kivy.uix.label`, :doc:`api-kivy.uix.button`,
     :doc:`api-kivy.uix.image`, :doc:`api-kivy.uix.slider`,
     :doc:`api-kivy.uix.progressbar`, :doc:`api-kivy.uix.textinput`,
-    :doc:`api-kivy.uix.togglebutton`, :doc:`api-kivy.uix.switch`
+    :doc:`api-kivy.uix.togglebutton`, :doc:`api-kivy.uix.switch`,
+    :doc:`api-kivy.uix.video`
 
 - **Layouts**: A layout widget has no rendering, just a trigger
   that will arrange its children in a specific way. Read more on
   :doc:`api-kivy.uix.layout`
 
     :doc:`api-kivy.uix.gridlayout`, :doc:`api-kivy.uix.boxlayout`,
-    :doc:`api-kivy.uix.anchorlayout`, :doc:`api-kivy.uix.stacklayout`,
+    :doc:`api-kivy.uix.anchorlayout`, :doc:`api-kivy.uix.stacklayout`
 
 - **Complex UX widgets**: Non-atomic widgets, result of classic widget
   combinations. We call them complex because the assembly and usages are not as
@@ -28,6 +29,7 @@ Read first: :doc:`api-kivy.uix.widget`
 
     :doc:`api-kivy.uix.bubble`,
     :doc:`api-kivy.uix.filechooser`, :doc:`api-kivy.uix.popup`,
+    :doc:`api-kivy.uix.videoplayer`,
     :doc:`api-kivy.uix.vkeyboard`
 
 - **Behaviors widgets**: Theses widgets have no rendering, but act on the graphics
