@@ -67,12 +67,17 @@ from kivy.uix.scrollview import ScrollView
 from kivy.uix.gridlayout import GridLayout
 from kivy.uix.label import Label
 from kivy.uix.image import AsyncImage
+from kivy.uix.videoplayer import VideoPlayer
+from kivy.uix.anchorlayout import AnchorLayout
 from kivy.animation import Animation
 from kivy.logger import Logger
 
 from docutils.parsers import rst
 from docutils.parsers.rst import roles
 from docutils import nodes, frontend, utils
+from docutils.parsers.rst import Directive, directives
+from docutils.parsers.rst.roles import set_classes
+
 
 #
 # Handle some additional roles
@@ -82,6 +87,22 @@ if 'KIVY_DOC' not in os.environ:
     class role_doc(nodes.Inline, nodes.TextElement):
         pass
 
+    class role_video(nodes.General, nodes.TextElement):
+        pass
+
+    class VideoDirective(Directive):
+        has_content = False
+        required_arguments = 1
+        optional_arguments = 0
+        final_argument_whitespace = True
+        option_spec = {'width': directives.nonnegative_int,
+                       'height': directives.nonnegative_int}
+
+        def run(self):
+            set_classes(self.options)
+            node = role_video(source=self.arguments[0], **self.options)
+            return [node]
+
     generic_docroles = {
         'doc': role_doc}
 
@@ -90,12 +111,15 @@ if 'KIVY_DOC' not in os.environ:
         role = roles.CustomRole(rolename, generic, {'classes': [rolename]})
         roles.register_local_role(rolename, role)
 
+    directives.register_directive('video', VideoDirective)
+
 Builder.load_string('''
 #:import parse_color kivy.parser.parse_color
 
 <RstDocument>:
     content: content
     scatter: scatter
+    do_scroll_x: False
     canvas:
         Color:
             rgb: .9, .905, .910
@@ -287,7 +311,17 @@ Builder.load_string('''
         Color:
             rgb: .2, .2, .2
         Line:
-            points: [self.x, self.y, self.right, self.y, self.right, self.top, self.x, self.top, self.x, self.y]
+            points: [\
+            self.x,\
+            self.y,\
+            self.right,\
+            self.y,\
+            self.right,\
+            self.top,\
+            self.x,\
+            self.top,\
+            self.x,\
+            self.y]
 
 <RstTransition>:
     size_hint_y: None
@@ -306,9 +340,24 @@ Builder.load_string('''
 
 <RstEmptySpace>:
     size_hint: 0.01, 0.01
+
+<RstVideoPlayer>:
+    options: {'allow_stretch': True}
+    canvas.before:
+        Color:
+            rgba: (1, 1, 1, 1)
+        BorderImage:
+            source: 'atlas://data/images/defaulttheme/player-background'
+            pos: self.x - 25, self.y - 25
+            size: self.width + 50, self.height + 50
+            border: (25, 25, 25, 25)
 ''')
 
 
+class RstVideoPlayer(VideoPlayer):
+    pass
+
+
 class RstDocument(ScrollView):
     '''Base widget used to store an Rst document. See module documentation for
     more information.
@@ -812,7 +861,8 @@ class _Visitor(nodes.NodeVisitor):
         elif cls is nodes.reference:
             name = node.get('name', node.get('refuri'))
             self.text += '[ref=%s][color=%s]' % (name,
-                    self.root.colors.get('link', self.root.colors.get('paragraph')))
+                    self.root.colors.get('link',
+                        self.root.colors.get('paragraph')))
             if 'refname' in node and 'name' in node:
                 self.root.refs_assoc[node['name']] = node['refname']
 
@@ -828,6 +878,9 @@ class _Visitor(nodes.NodeVisitor):
         elif cls is role_doc:
             self.doc_index = len(self.text)
 
+        elif cls is role_video:
+            pass
+
     def dispatch_departure(self, node):
         cls = node.__class__
         #print '<--', cls
@@ -948,6 +1001,17 @@ class _Visitor(nodes.NodeVisitor):
                     self.colorize(title, 'link'))
             self.text = self.text[:self.doc_index] + text
 
+        elif cls is role_video:
+            width = node['width'] if 'width' in node.attlist() else 400
+            height = node['height'] if 'height' in node.attlist() else 300
+            video = RstVideoPlayer(
+                    source=node['source'],
+                    size_hint=(None, None),
+                    size=(width, height))
+            anchor = AnchorLayout(size_hint_y=None, height=height + 20)
+            anchor.add_widget(video)
+            self.current.add_widget(anchor)
+
     def set_text(self, node, parent):
         text = self.text
         if parent == 'term' or parent == 'field_name':
@@ -965,3 +1029,7 @@ class _Visitor(nodes.NodeVisitor):
             self.root.colors.get(name, self.root.colors['paragraph']),
             text)
 
+if __name__ == '__main__':
+    from kivy.base import runTouchApp
+    import sys
+    runTouchApp(RstDocument(source=sys.argv[1]))
