@@ -75,6 +75,7 @@ properties of that class.
     numeric        :class:`SettingNumeric`
     options        :class:`SettingOptions`
     string         :class:`SettingString`
+    path           :class:`SettingPath` (new from 1.1.0)
     ============== =================================================
 
 In the JSON example above, the first element is of type "title". It will create
@@ -101,15 +102,17 @@ To load the JSON example to a :class:`Settings` instance, use the
 
 '''
 
-__all__ = ('Settings', 'SettingsPanel',
-           'SettingItem', 'SettingBoolean', 'SettingNumeric',
+__all__ = ('Settings', 'SettingsPanel', 'SettingItem', 'SettingString',
+           'SettingPath', 'SettingBoolean', 'SettingNumeric',
            'SettingOptions')
 
 import json
+import os
 from kivy.config import ConfigParser
 from kivy.animation import Animation
 from kivy.uix.boxlayout import BoxLayout
 from kivy.uix.button import Button
+from kivy.uix.filechooser import FileChooserListView
 from kivy.uix.floatlayout import FloatLayout
 from kivy.uix.gridlayout import GridLayout
 from kivy.uix.label import Label
@@ -317,9 +320,15 @@ class SettingString(SettingItem):
             return
         self.bind(on_release=self._create_popup)
 
-    def _validate(self, instance):
-        self.popup.dismiss()
+    def _dismiss(self, *largs):
+        if self.textinput:
+            self.textinput.focus = False
+        if self.popup:
+            self.popup.dismiss()
         self.popup = None
+
+    def _validate(self, instance):
+        self._dismiss()
         value = self.textinput.text.strip()
         if value == '':
             return
@@ -349,7 +358,84 @@ class SettingString(SettingItem):
         btn.bind(on_release=self._validate)
         btnlayout.add_widget(btn)
         btn = Button(text='Cancel')
-        btn.bind(on_release=popup.dismiss)
+        btn.bind(on_release=self._dismiss)
+        btnlayout.add_widget(btn)
+        content.add_widget(btnlayout)
+
+        # all done, open the popup !
+        popup.open()
+
+
+class SettingPath(SettingItem):
+    '''Implementation of a Path setting on top of :class:`SettingItem`.
+    It's visualized with a :class:`~kivy.uix.label.Label` widget that, when
+    clicked, will open a :class:`~kivy.uix.popup.Popup` with a
+    :class:`~kivy.uix.filechooser.FileChooserListView` so the user can enter
+    a custom value.
+
+    .. versionadded:: 1.1.0
+    '''
+
+    popup = ObjectProperty(None, allownone=True)
+    '''(internal) Used to store the current popup when it's shown
+
+    :data:`popup` is a :class:`~kivy.properties.ObjectProperty`, default to
+    None.
+    '''
+
+    textinput = ObjectProperty(None)
+    '''(internal) Used to store the current textinput from the popup, and listen
+    for changes.
+
+    :data:`popup` is a :class:`~kivy.properties.ObjectProperty`, default to
+    None.
+    '''
+
+    def on_panel(self, instance, value):
+        if value is None:
+            return
+        self.bind(on_release=self._create_popup)
+
+    def _dismiss(self, *largs):
+        if self.textinput:
+            self.textinput.focus = False
+        if self.popup:
+            self.popup.dismiss()
+        self.popup = None
+
+    def _validate(self, instance):
+        self._dismiss()
+        value = self.textinput.selection
+
+        if not value:
+            return
+
+        self.value = os.path.realpath(value[0])
+
+    def _create_popup(self, instance):
+        # create popup layout
+        content = BoxLayout(orientation='vertical', spacing=5)
+        self.popup = popup = Popup(title=self.title,
+            content=content, size_hint=(None, None), size=(400, 400))
+
+        # create the filechooser
+        self.textinput = textinput = FileChooserListView(path=str(self.value),
+                                                         size_hint=(1, 1),
+                                                         dirselect=True)
+        textinput.bind(on_path=self._validate)
+        self.textinput = textinput
+
+        # construct the content
+        content.add_widget(textinput)
+        content.add_widget(SettingSpacer())
+
+        # 2 buttons are created for accept or cancel the current value
+        btnlayout = BoxLayout(size_hint_y=None, height=50, spacing=5)
+        btn = Button(text='Ok')
+        btn.bind(on_release=self._validate)
+        btnlayout.add_widget(btn)
+        btn = Button(text='Cancel')
+        btn.bind(on_release=self._dismiss)
         btnlayout.add_widget(btn)
         content.add_widget(btnlayout)
 
@@ -365,13 +451,11 @@ class SettingNumeric(SettingString):
     '''
 
     def _validate(self, instance):
-        self.popup.dismiss()
-        self.popup = None
+        self._dismiss()
         try:
-            value = int(self.textinput.text)
+            self.value = int(self.textinput.text)
         except ValueError:
             return
-        self.value = value
 
 
 class SettingOptions(SettingItem):
@@ -539,6 +623,7 @@ class Settings(BoxLayout):
         self.register_type('numeric', SettingNumeric)
         self.register_type('options', SettingOptions)
         self.register_type('title', SettingTitle)
+        self.register_type('path', SettingPath)
 
     def on_menu(self, instance, value):
         if value and self.content:
@@ -593,6 +678,7 @@ class Settings(BoxLayout):
             str_settings = {}
             for key, item in setting.iteritems():
                 str_settings[str(key)] = item
+
             instance = cls(panel=panel, **str_settings)
 
             # instance created, add to the panel
