@@ -106,6 +106,7 @@ import sys
 from functools import partial
 from kivy.logger import Logger
 from kivy.utils import boundary
+from kivy.utils import platform
 from kivy.clock import Clock
 from kivy.cache import Cache
 from kivy.core.text import Label
@@ -133,20 +134,12 @@ class TextInputCutCopyPaste(Bubble):
     def do(self, action):
         textinput = self.textinput
 
-        global Clipboard
-        if Clipboard is None:
-            from kivy.core.clipboard import Clipboard
-
         if action == 'cut':
-            Clipboard.put(textinput.selection_text, 'text/plain')
-            textinput.delete_selection()
+            textinput._cut(textinput.selection_text)
         elif action == 'copy':
-            Clipboard.put(textinput.selection_text, 'text/plain')
+            textinput._copy(textinput.selection_text)
         elif action == 'paste':
-            data = Clipboard.get('text/plain')
-            if data:
-                textinput.delete_selection()
-                textinput.insert_text(data)
+            textinput._paste()
 
 
 class TextInput(Widget):
@@ -271,7 +264,11 @@ class TextInput(Widget):
         text = self._lines[cr]
         new_text = text[:cc] + substring + text[cc:]
         self._set_line_text(cr, new_text)
-        self._trigger_refresh_text()
+        if len(substring) > 1 or substring == '\n':
+            # Avoid refreshing text on every keystroke.
+            # Allows for faster typing of text when the amount of text in
+            # TextInput gets large.
+            self._trigger_refresh_text()
         self.cursor = self.get_cursor_from_index(ci + len(substring))
 
     def do_backspace(self):
@@ -297,7 +294,10 @@ class TextInput(Widget):
             new_text = text[:cc-1] + text[cc:]
             self._set_line_text(cr, new_text)
 
-        self._refresh_text_from_property()
+        # refresh_text seems to be unnecessary here
+        # plus removing it leads to a large improvement in editing text
+        # where large..ish text is involved.
+        #self._refresh_text_from_property()
         self.cursor = self.get_cursor_from_index(cursor_index - 1)
 
     def do_cursor_movement(self, action):
@@ -404,7 +404,11 @@ class TextInput(Widget):
         else:
             self._selection = bool(len(self.selection_text))
             self._selection_touch = None
-        self._trigger_update_graphics()
+        if a == 0:
+            # update graphics only on new line
+            # allows smoother scrolling, noticeably
+            # faster when dealing with large text.
+            self._trigger_update_graphics()
 
     #
     # Touch control
@@ -525,7 +529,7 @@ class TextInput(Widget):
             # we got argument, it could be the previous schedule
             # cancel focus.
             if len(largs):
-                Logger.warning('Textinput: '
+                Logger.warning('Textinput: ' +
                     'Cannot focus the element, unable to get root window')
                 return
             else:
@@ -548,6 +552,51 @@ class TextInput(Widget):
             Clock.unschedule(self._do_blink_cursor)
             self._win = None
 
+    def _ensure_clipboard(self):
+        global Clipboard
+        if Clipboard is not None:
+            return
+        from kivy.core.clipboard import Clipboard
+        _platform = platform()
+        if _platform == 'win':
+            self._clip_mime_type = 'text/plain;charset=utf-8'
+            #windows clipboard uses a utf-16 encoding
+            self._encoding = 'utf-16'
+        elif _platform == 'linux':
+            self._clip_mime_type = 'UTF8_STRING'
+            self._encoding = 'utf-8'
+        else:
+            self._clip_mime_type = 'text/plain'
+            self._encoding = 'utf-8'
+
+    def _cut(self, data):
+        self._copy(data)
+        self.delete_selection()
+
+    def _copy(self, data):
+        # explicitly terminate strings with a null character
+        # so as to avoid putting spurious data after the end.
+        # MS windows issue.
+        self._ensure_clipboard()
+        data = data.encode(self._encoding) + '\x00'
+        Clipboard.put(data, self._clip_mime_type)
+
+    def _paste(self):
+        self._ensure_clipboard()
+        _clip_types = Clipboard.get_types()
+
+        mime_type = self._clip_mime_type
+        if mime_type not in _clip_types:
+            mime_type = 'text/plain'
+
+        data = Clipboard.get(mime_type)
+        if data is not None:
+            data = data.decode(self._encoding, 'ignore')
+            # remove null strings mostly a windows issue
+            data = data.replace('\x00', '')
+            self.delete_selection()
+            self.insert_text(data)
+
     def _keyboard_released(self):
         # Callback called when the real keyboard is taken by someone else
         # called by the window if the keyboard is taken by somebody else
@@ -559,7 +608,9 @@ class TextInput(Widget):
         if not self._label_cached:
             self._get_line_options()
         text = text.replace('\t', ' ' * self.tab_width)
-        return self._label_cached.get_extents(text)[0]
+        if not self.password:
+            return self._label_cached.get_extents(text)[0]
+        return self._label_cached.get_extents('*' * len(text))[0]
 
     def _do_blink_cursor(self, dt):
         # Callback called by the timer to blink the cursor, according to the
@@ -608,17 +659,19 @@ class TextInput(Widget):
         # By using cache in internal functions, this method should be fast.
         _lines, self._lines_flags = self._split_smart(text)
         self._lines = _lines
-        self._lines_labels = [self._create_line_label(x) for x in self._lines]
+        _create_label = self._create_line_label
+        _lines_labels = self._lines_labels =\
+            [_create_label(x) for x in _lines]
         self._lines_rects = [Rectangle(texture=x, size=( \
                              x.size if x else (0, 0))) \
-                             for x in self._lines_labels]
-        line_label = self._lines_labels[0]
+                             for x in _lines_labels]
+        line_label = _lines_labels[0]
         if line_label is None:
             self.line_height = max(1, self.font_size + self.padding_y)
         else:
             self.line_height = line_label.height
         self._line_spacing = 2
-        # now, if the text change, maybe the cursor is not as the same place as
+        # now, if the text change, maybe the cursor is not at the same place as
         # before. so, try to set the cursor on the good place
         row = self.cursor_row
         self.cursor = self.get_cursor_from_index(self.cursor_index())
@@ -724,11 +777,24 @@ class TextInput(Widget):
         self.canvas.remove_group('selection')
         dy = self.line_height + self._line_spacing
         rects = self._lines_rects
-        y = self.top - self.padding_y + self.scroll_y
-        miny = self.y + self.padding_y
-        maxy = self.top - self.padding_y
+        _padding_y = self.padding_y
+        _top = self.top
+        y = _top - _padding_y + self.scroll_y
+        miny = self.y + _padding_y
+        maxy = _top - _padding_y
         draw_selection = self._draw_selection
-        for line_num, value in enumerate(self._lines):
+        scroll_y = self.scroll_y
+        a, b = self.selection_from, self.selection_to
+        if a > b:
+            a, b = b, a
+        get_cursor_from_index = self.get_cursor_from_index
+        s1c, s1r = get_cursor_from_index(a)
+        s2c, s2r = get_cursor_from_index(b)
+        s2r += 1
+        # pass only the selection lines
+        # passing all the lines can get slow when dealing with a lot of text
+        y -= s1r * dy
+        for line_num, value in enumerate(self._lines[s1r:s2r], start=s1r):
             if miny <= y <= maxy + dy:
                 r = rects[line_num]
                 draw_selection(r.pos, r.size, line_num)
@@ -739,8 +805,9 @@ class TextInput(Widget):
         a, b = self.selection_from, self.selection_to
         if a > b:
             a, b = b, a
-        s1c, s1r = self.get_cursor_from_index(a)
-        s2c, s2r = self.get_cursor_from_index(b)
+        get_cursor_from_index = self.get_cursor_from_index
+        s1c, s1r = get_cursor_from_index(a)
+        s2c, s2r = get_cursor_from_index(b)
         if line_num < s1r or line_num > s2r:
             return
         x, y = pos
@@ -753,12 +820,14 @@ class TextInput(Widget):
         if line_num == s2r:
             lines = self._lines[line_num]
             x2 = x + self._get_text_width(lines[:s2c])
-        maxx = x + self.width - self.padding_x
+        width_minus_padding_x = self.width - self.padding_x
+        maxx = x + width_minus_padding_x
         if x1 > maxx:
             return
-        x2 = min(x2, self.x + self.width - self.padding_x)
-        self.canvas.add(Color(*self.selection_color, group='selection'))
-        self.canvas.add(Rectangle(
+        x2 = min(x2, self.x + width_minus_padding_x)
+        canvas_add = self.canvas.add
+        canvas_add(Color(*self.selection_color, group='selection'))
+        canvas_add(Rectangle(
             pos=(x1, pos[1]), size=(x2 - x1, size[1]), group='selection'))
 
     def on_size(self, instance, value):
@@ -793,6 +862,8 @@ class TextInput(Widget):
     def _create_line_label(self, text):
         # Create a label from a text, using line options
         ntext = text.replace('\n', '').replace('\t', ' ' * self.tab_width)
+        if self.password:
+            ntext = '*' * len(ntext)
         kw = self._get_line_options()
         cid = '%s\0%s' % (ntext, str(kw))
         texture = Cache.get('textinput.label', cid)
@@ -909,10 +980,6 @@ class TextInput(Widget):
                 self._update_selection(True)
 
     def _keyboard_on_key_down(self, window, keycode, text, modifiers):
-        global Clipboard
-        if Clipboard is None:
-            from kivy.core.clipboard import Clipboard
-
         is_osx = sys.platform == 'darwin'
         # Keycodes on OSX:
         ctrl, cmd = 64, 1024
@@ -922,15 +989,11 @@ class TextInput(Widget):
             # This allows *either* ctrl *or* cmd, but not both.
             if modifiers == ['ctrl'] or (is_osx and modifiers == ['meta']):
                 if key == ord('x'): # cut selection
-                    Clipboard.put(self.selection_text, 'text/plain')
-                    self.delete_selection()
+                    self._cut(self.selection_text)
                 elif key == ord('c'): # copy selection
-                    Clipboard.put(self.selection_text, 'text/plain')
+                    self._copy(self.selection_text)
                 elif key == ord('v'): # paste selection
-                    data = Clipboard.get('text/plain')
-                    if data:
-                        self.delete_selection()
-                        self.insert_text(data)
+                    self._paste()
                 elif key == ord('a'): # select all
                     self.selection_from = 0
                     self.selection_to = len(self.text)
@@ -975,6 +1038,15 @@ class TextInput(Widget):
     True
     '''
 
+    password = BooleanProperty(False)
+    '''If True, the widget will display its characters as the character*.
+
+    .. versionadded:: 1.2.0
+
+    :data:`password` is a :class:`~kivy.properties.BooleanProperty`, default to
+    False
+    '''
+
     cursor_blink = BooleanProperty(False)
     '''This property is used to blink the cursor graphics. The value of
     :data:`cursor_blink` is automatically computed, setting a value on it will
@@ -1130,6 +1202,24 @@ class TextInput(Widget):
     to [0.1843, 0.6549, 0.8313, .5]
     '''
 
+    background_color = ListProperty([1, 1, 1, 1])
+    '''Current color of the background, in (r, g, b, a) format.
+
+    .. versionadded:: 1.2.0
+
+    :data:`background_color` is a :class:`~kivy.properties.ListProperty`,
+    default to [1, 1, 1, 1] #White
+    '''
+
+    foreground_color = ListProperty([0, 0, 0, 1])
+    '''Current color of the foreground, in (r, g, b, a) format.
+
+    .. versionadded:: 1.2.0
+
+    :data:`foreground_color` is a :class:`~kivy.properties.ListProperty`,
+    default to [0, 0, 0, 1] #Black
+    '''
+
     selection_from = NumericProperty(None, allownone=True)
     '''If a selection is happening, or finished, this property will represent
     the cursor index where the selection start.
